@@ -1,6 +1,6 @@
 class MMFibreCoverage:
     VALUES = [
-        ("CoberturaMM", "Fibra (FTTH)"),
+        ("fibraFTTH", "Fibra (FTTH)"),
         ("NoFibra", "No Fibra (MM)"),
         ("NoRevisat", "No revisat"),
         ("fibraIndirecta", "Fibra (indirecta)")
