@@ -1,7 +1,7 @@
 class VdfFibreCoverage:
     VALUES = [
-        ("FibraCoaxial", "Fibra (coaxial)"),
-        ("FibraVdf", "Fibra (FTTH)"),
+        ("fibraCoaxial", "Fibra (coaxial)"),
+        ("fibraFTTH", "Fibra (FTTH)"),
         ("NEBAFTTH", "Fibra (NEBA)"),
         ("NoFibraVdf", "No fibra"),
         ("NoRevisat", "No revisat")
