@@ -9,7 +9,7 @@ class CoverageArticle(AbstractArticle):
     dynamic_fields_names = (
         "tipusVia", "nomVia", "numero", "bloc", "portal", "pis", "escala", "porta",
         "poblacioServei", "provinciaServei", "codiProvinciaServei", "CPservei", "altresCobertura",
-        "coberturaADSL", "coberturaFibraMM", "coberturaFibraVdf", "IDhogar"
+        "coberturaADSL", "coberturaFibraMM", "coberturaFibraVdf", "coberturaFibraOrange", "IDhogar"
     )
     subject = "Sol·licitud cobertura"
 
