@@ -7,6 +7,7 @@ class FiberData(InternetData):
     def __init__(self, **args):
         self.previous_contract_pon = args.get("previous_contract_pon", "")
         self.previous_contract_fiber_speed = args.get("previous_contract_fiber_speed", "")
-        args.pop("previous_contract_pon", None)
-        args.pop("previous_contract_fiber_speed", None)
+        self.activation_notes = args.get("activation_notes", "")
+        for key in ["previous_contract_pon", "previous_contract_fiber_speed", "activation_notes"]:
+            args.pop(key, None)
         super().__init__(**args)
