@@ -43,7 +43,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
 
     def _previous_provider(self):
         provider = None
-        if self.service_data.change_address == "no":
+        if self.service_data.type != "location_change":
             provider = self.service_data.previous_provider
         return DynamicField(name="proveidorPrevi", value=provider)
 
@@ -108,7 +108,8 @@ class InternetDynamicFields(ProvisionDynamicFields):
         return DynamicField(name="direccioServeiAntic", value=self.service_data.previous_contract_address)
 
     def _change_address(self):
-        return DynamicField(name="canviUbicacioMateixTitular", value=self.service_data.change_address)
+        change_address = "yes" if self.service_data.type == "location_change" else "no"
+        return DynamicField(name="canviUbicacioMateixTitular", value=change_address)
 
     def _change_address_provider(self):
         return DynamicField(name="proveidorPreviCU", value=self.service_data.previous_internal_provider)
