@@ -19,6 +19,7 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._subdivision(),
             self._has_sim(),
             self._sim_received(),
+            self._activation_notes(),
             self._send_sim_type(),
             self._delivery_street(),
             self._delivery_zip_code(),
@@ -56,6 +57,12 @@ class MobileDynamicFields(ProvisionDynamicFields):
     def _has_sim(self):
         return DynamicField("noCobrarSIM", self.service_data.has_sim)
 
+    def _activation_notes(self):
+        return DynamicField(
+            name="consideracionsActivacio",
+            value=self.service_data.activation_notes
+        )
+
     def _sim_received(self):
         return DynamicField("SIMrebuda", self.service_data.has_sim)
 
