@@ -79,6 +79,22 @@ class MobileProcessTicket:
     def product_code(self):
         return self.response.dynamic_field_get('productMobil').value
 
+    @property
+    def delivery_street(self):
+        return self.response.dynamic_field_get('direccioEnviament').value
+
+    @property
+    def delivery_city(self):
+        return self.response.dynamic_field_get('poblacioEnviament').value
+
+    @property
+    def delivery_zip_code(self):
+        return self.response.dynamic_field_get('CPenviament').value
+
+    @property
+    def delivery_state(self):
+        return self.response.dynamic_field_get('provinciaEnviament').value
+
     def confirmed(self):
         return self.state == 'closed successful'
 
