@@ -2,5 +2,6 @@ class Providers:
     VALUES = [
         ('scJazztel', 'SC-Jazztel (ADSL)'),
         ('scMM', 'SC-MM'),
-        ('scVdf', 'SC-Vdf')
+        ('scVdf', 'SC-Vdf'),
+        ('scOrange', 'SC-Orange (Fiber)')
     ]
