@@ -24,7 +24,9 @@ class Service():
             not self._field('coberturaADSL') or self._field('coberturaADSL') not in NO_COVERAGE_VALUES)
 
     def _has_fibre_coverage(self):
-        return self._is_fibre() and (self._fibre_MM_coverage() or self._fibre_Vdf_coverage())
+        return self._is_fibre() and (
+            self._fibre_MM_coverage() or self._fibre_Vdf_coverage() or self._fibre_Orange_coverage()
+        )
 
     def _fibre_MM_coverage(self):
         return not self._field('coberturaFibraMM') or self._field('coberturaFibraMM') not in NO_COVERAGE_VALUES
@@ -32,6 +34,9 @@ class Service():
     def _fibre_Vdf_coverage(self):
         return not self._field('coberturaFibraVdf') or self._field('coberturaFibraVdf') not in NO_COVERAGE_VALUES
 
+    def _fibre_Orange_coverage(self):
+        return not self._field('coberturaFibraOrange') or self._field('coberturaFibraOrange') not in NO_COVERAGE_VALUES
+
     def has_coverage(self):
         return self.is_mobile() or self._has_adsl_coverage() or self._has_fibre_coverage()
 
