@@ -1,7 +1,7 @@
 import os
 import unittest
 import json
-from mock import patch
+from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.customer_user import CustomerUser
 
@@ -35,6 +35,9 @@ class ChangeCustomerUserIntegrationTestCase(unittest.TestCase):
             }
         }
 
+        requests_mock.post.return_value = Mock(spec=['json'])
+        requests_mock.post.return_value.json.return_value = {"Result": [1]}
+
         CustomerUser(user_id).change_language(lang)
 
         requests_mock.post.assert_called_once_with(expected_url, data=json.dumps(expected_body))
