@@ -20,7 +20,6 @@ class MobileTicketResponseTestCase(unittest.TestCase):
             {"Name": "NIFNIEtitular", "Value": "123456789F"},
             {"Name": "IBAN", "Value": "ES9000246912501234567891"},
             {"Name": "dataIniciFacturacio", "Value": "2018-12-10 00:00:00"},
-            {"Name": "notes", "Value": "Notes..."},
         ]
 
         ticket = MobileProcessTicket(Ticket(OTRSTicketGetResponse), Mock(spec=[]))
@@ -42,7 +41,6 @@ class MobileTicketResponseTestCase(unittest.TestCase):
 
         expected_date = datetime.strptime("2018-12-10 00:00:00", "%Y-%m-%d %H:%M:%S")
         self.assertEqual(expected_date, ticket.invoices_start_date)
-        self.assertEqual("Notes...", ticket.notes)
 
     def test_otrs_ticket_get_parse_response_mobile(self):
         OTRSTicketGetResponse['DynamicField'] = [
