@@ -51,7 +51,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'orange_fiber_coverage',
-            'change_address',
+            'type',
             'product',
             'previous_internal_provider',
         ])
@@ -185,7 +185,6 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "Nubip"
-        self.service_data.change_address = "no"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
@@ -419,20 +418,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["coberturaFibraOrange"], "fibraFTTH")
 
-    def test_change_address_field(self):
-        self.service_data.change_address = "yes"
-
-        dynamic_fields = ADSLDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
-
-# Service Dynamic Fields
+    # Service Dynamic Fields
     def test_landline_number_field(self):
         self.service_data.landline_phone_number = "666666666"
 
@@ -472,8 +458,40 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
-    def test_previous_provider_not_exists_in_change_address(self):
-        self.service_data.change_address = True
+    def test_type_field_location_change(self):
+        self.service_data.type = "location_change"
+        self.service_data.previous_owner_name = "A"
+        self.service_data.previous_owner_surname = "B"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
+        self.assertEqual(dynamic_fields_dct["nomCognomSociAntic"], "A B")
+
+    def test_type_field_non_location_change(self):
+        self.service_data.type = "portability"
+        self.service_data.previous_owner_name = "A"
+        self.service_data.previous_owner_surname = "B"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
+        self.assertNotIn("nomCognomSociAntic", dynamic_fields_dct.keys())
+
+    def test_previous_provider_does_not_exist_when_location_change(self):
+        self.service_data.type = 'location_change'
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
