@@ -48,6 +48,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'previous_owner_name',
             'previous_owner_surname',
             'notes',
+            'activation_notes',
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
@@ -553,3 +554,16 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
+
+    def test_activivation_notes_field(self):
+        self.service_data.activation_notes = "text text text"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["consideracionsActivacio2"], "text text text")
