@@ -49,6 +49,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'delivery_city',
             'delivery_zip_code',
             'delivery_state',
+            'activation_notes',
         ])
         self.mobile_data.type = 'new'
 
@@ -429,3 +430,15 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaEnviament"], "ES-A")
 
+    def test_activation_notes_field(self):
+        self.mobile_data.activation_notes = "text text text"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["consideracionsActivacio"], "text text text")
\ No newline at end of file
